@@ -1020,7 +1020,9 @@ class DiffConfig:
         self.apply_rules(old_cfg)
 
         if self._dump_config:
-            print(">> old configuration (after rules, if specified):",
+            print(">>"
+                  + (" old" if new_cfg else "")
+                  + " configuration (after rules, if specified):",
                   yaml.dump(deepselect(dict(old_cfg),
                                        *self._subtree_dump_filter),
                             default_flow_style=False),
