@@ -15,11 +15,6 @@ This module parses Cisco IOS configuration files into a dictionary.
 
 
 
-import re
-
-from deepops import deepsetdefault, deepget
-from netaddr import IPNetwork
-
 from net_contextdiff.config import IndentedContextualConfig
 
 from .commands import commands
